@@ -3,7 +3,7 @@ package App::Maisha::Plugin::Twitter;
 use strict;
 use warnings;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -90,8 +90,12 @@ sub login {
     }
 
     $self->api($api);
-    print "...building user cache for Twitter\n";
-    $self->_build_users();
+
+    if(!$config->{test}) {
+        print "...building user cache for Twitter\n";
+        $self->_build_users();
+    }
+
     return 1;
 }
 
@@ -254,9 +258,11 @@ and provide a PIN (Personal Identification Number) to allow the application to
 retrieve access tokens.
 
 With this new method of authentication, the application will provide a URL,
-which the user needs to cut-n-paste into a browser. You will then need to login
-to the service, using your regular username/password. You will then be given a
-PIN, which should then be entered at the prompt on the command line.
+which the user needs to cut-n-paste into a browser to logging in to the 
+service, using your regular username/password, then 'Allow' Maisha to access 
+your account. This will then allow Maisha to post to your account. You will 
+then be given a PIN, which should then be entered at the prompt on the Maisha
+command line.
 
 Once you have completed authentication, the application will then store your 
 access tokens permanently under your profile on your computer. Then when you
